Package: FAfA
Title: Factor Analysis for All
Version: 1.0
Date: 2026-04-29
Authors@R: c(
    person("Abdullah Faruk", "KILIC", , "afarukkilic@trakya.edu.tr", role = c("aut", "cre")),
    person("Ahmet", "Caliskan", , "ahmetcaliskan1987@gmail.com", role = "aut")
  )
Description: Provides a comprehensive Shiny-based graphical user interface
    for conducting a wide range of factor analysis procedures. 'FAfA'
    (Factor Analysis for All) guides users through data uploading,
    assumption checking (descriptives, collinearity, multivariate
    normality, outliers), data wrangling (variable exclusion, data
    splitting), factor retention analysis (e.g., Parallel Analysis, Hull
    method, EGA), Exploratory Factor Analysis (EFA) with various rotation
    and extraction methods, Confirmatory Factor Analysis (CFA) for model
    testing, Reliability Analysis (e.g., Cronbach's Alpha, McDonald's
    Omega), Measurement Invariance testing across groups, and item
    weighting techniques. The application leverages established R packages
    such as 'lavaan' and 'psych' to perform these analyses, offering an
    accessible platform for researchers and students. Results are
    presented in user-friendly tables and plots, with options for
    downloading outputs.
License: MIT + file LICENSE
URL: https://github.com/AFarukKILIC/FAfA
BugReports: https://github.com/AFarukKILIC/FAfA/issues
Imports: Amelia, EFA.MRFA, EFA.dimensions, EFAtools, EGAnet, ItemRest,
        MBESS, bsicons, bslib, config, dplyr, ggcorrplot, ggplot2,
        golem, grDevices, graphics, haven, lavaan, magrittr, mctest,
        mice, missForest, moments, mvnormalTest, naniar, pastecs,
        psych, psychometric, readxl, semPlot, semTools, shiny,
        shinycssloaders, sirt, stats, tools, utils
Suggests: spelling, testthat (>= 3.0.0)
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-29 21:05:48 UTC; Faruk
Author: Abdullah Faruk KILIC [aut, cre],
  Ahmet Caliskan [aut]
Maintainer: Abdullah Faruk KILIC <afarukkilic@trakya.edu.tr>
Depends: R (>= 4.1.0)
Repository: CRAN
Date/Publication: 2026-04-29 21:40:09 UTC
Built: R 4.6.0; ; 2026-04-30 02:10:45 UTC; unix
