% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mod_itemrest_ui.r
\name{mod_itemrest_ui}
\alias{mod_itemrest_ui}
\title{ItemRest Analysis UI Module}
\usage{
mod_itemrest_ui(id)
}
\arguments{
\item{id}{Module namespace ID.}
}
\description{
ItemRest Analysis UI Module
}
