% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_app.R
\name{run_app}
\alias{run_app}
\title{Run the Shiny Application}
\usage{
run_app()
}
\description{
This function launches the Shiny application.
It uses default options for \code{shinyApp} and golem.
}
