% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mod_about_server.r
\name{about_server}
\alias{about_server}
\title{About Server Module}
\usage{
about_server(id)
}
\arguments{
\item{id}{Module namespace ID.}
}
\description{
About Server Module
}
